@@ -124,7 +124,7 @@ def cli():
 
     Workflow Template Manipulation
     ==============================
-    dsf-cli workflow-template <create / delete / instantiate>
+    dsf-cli workflow-template <create / create_yaml / delete / instantiate>
 
     DAG Manipulation
     ================
@@ -297,9 +297,9 @@ def dataproc_cluster(action: str):
 def workflow_template(action: str):
     """! Handle workflow action, either create, instantiate or delete the template
         Args:
-             action: an action to perform, chosen from: {create, instantiate, delete}
+             action: an action to perform, chosen from: {create, create_yaml, instantiate, delete}
     """
-    valid_actions = {'create', 'delete', 'instantiate'}
+    valid_actions = {'create', 'create_yaml', 'delete', 'instantiate'}
     if action not in valid_actions:
         print(f"Can't determine action type: {action}. Please use one of: {valid_actions}")
         return
